RunnablePassthrough

Struct RunnablePassthrough 

pub struct RunnablePassthrough;
Passes the input through unchanged. Useful in parallel compositions where one branch should preserve the original input.

Implementations

Source

impl RunnablePassthrough

pub fn assign( branches: Vec<(String, BoxRunnable<Value, Value>)>, ) -> RunnableAssign

Create a RunnableAssign that passes input through and merges additional computed keys.